# Welcome to GNATSS!

GNATSS is an open-source software for processing Global Navigation Satellite
Systems - Acoustic (GNSS-A) data for seafloor horizontal positioning. The
software is a redevelopment of existing FORTRAN codes and shell scripts
developed by C. David Chadwell for processing data including measurements made
with Wave Gliders. Existing code, which includes proprietary routines, is
developed and maintained by John DeSanto.

## Project overview

Near-Trench Community Geodetic Experiment is a five-year NSF-funded project that
will establish open and accessible seafloor deformation data offshore Alaska and
Cascadia, in regions responsible for some of the largest earthquakes and
tsunamis ever recorded.

Check out the [Seafloor Geodesy](https://www.seafloorgeodesy.org/) website for
more information about the community project.

## GNATSS - Fortran Benchmark

We've created a simple Jupyter Notebook to benchmark GNATSS results against
Chadwell's Fortran code results. The repository for this benchmarking can be
found in the Seafloor Geodesy Github Organization repository called
[gnatss-fortran-benchmark](https://github.com/seafloor-geodesy/gnatss-fortran-benchmark).
The rendered version of the main notebook can also be viewed
[here](https://nbviewer.org/github/seafloor-geodesy/gnatss-fortran-benchmark/blob/main/main.ipynb).

## Table of contents

```{tableofcontents}

```
